@@ -18,8 +18,8 @@ def directory_browse(directory: str = "",
                      filter_blenlib: bool = False,
                      filemode: int = 9,
                      relative_path: bool = True,
-                     display_type: typing.Union[str, int] = 'DEFAULT',
-                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+                     display_type: typing.Union[int, str] = 'DEFAULT',
+                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Open a directory browser, Hold Shift to open the file, Alt to browse containing directory
 
     :param directory: Directory, Directory of the file
@@ -55,9 +55,9 @@ def directory_browse(directory: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -79,8 +79,8 @@ def file_browse(filepath: str = "",
                 filter_blenlib: bool = False,
                 filemode: int = 9,
                 relative_path: bool = True,
-                display_type: typing.Union[str, int] = 'DEFAULT',
-                sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+                display_type: typing.Union[int, str] = 'DEFAULT',
+                sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Open a file browser, Hold Shift to open the file, Alt to browse containing directory
 
     :param filepath: File Path, Path to file
@@ -116,9 +116,9 @@ def file_browse(filepath: str = "",
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
