@@ -55,14 +55,14 @@ def brush_move(type: typing.Union[int, str] = 'UP'):
     pass
 
 
-def brush_paint(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def brush_paint(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                wait_for_input: bool = True):
     ''' Apply tweaks to strokes by painting over the strokes
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Enter a mini 'sculpt-mode' if enabled, otherwise, exit after drawing a single stroke
     :type wait_for_input: bool
     '''
@@ -185,15 +185,17 @@ def dissolve():
 
 
 def draw(mode: typing.Union[int, str] = 'DRAW',
-         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                              'bpy_prop_collection'] = None,
+         stroke: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+               List['bpy.types.OperatorStrokeElement'],
+               'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Grease Pencil strokes.
     :type mode: typing.Union[int, str]
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     '''
@@ -561,14 +563,15 @@ def select_grouped(type: typing.Union[int, str] = 'LAYER'):
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select Grease Pencil strokes using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
