@@ -4,17 +4,18 @@ import bpy.types
 
 
 def add_and_link_node(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
         type: str = "",
-        settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                               'bpy_prop_collection'] = None,
         use_transform: bool = False,
         link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param link_socket_index: Link Socket Index, Index of the socket to link
@@ -104,16 +105,18 @@ def add_mask(name: str = "Mask"):
     pass
 
 
-def add_node(type: str = "",
-             settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                                    'bpy_prop_collection'] = None,
-             use_transform: bool = False):
+def add_node(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+        type: str = "",
+        use_transform: bool = False):
     ''' Add a node to the active tree
 
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     '''
@@ -121,13 +124,14 @@ def add_node(type: str = "",
     pass
 
 
-def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                   'bpy_prop_collection'] = None,
+def add_reroute(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                 cursor: int = 6):
     ''' Add a reroute node
 
     :param path: path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -135,17 +139,19 @@ def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def add_search(type: str = "",
-               settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                                      'bpy_prop_collection'] = None,
-               use_transform: bool = False,
-               node_item: typing.Union[int, str] = ''):
+def add_search(
+        settings: typing.
+        Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.
+              List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+        type: str = "",
+        use_transform: bool = False,
+        node_item: typing.Union[int, str] = ''):
     ''' Add a node to the active tree
 
+    :param settings: Settings, Settings to be applied on the newly created node
+    :type settings: typing.Union[typing.Dict[str, 'bpy.types.NodeSetting'], typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param type: Node Type, Node type
     :type type: str
-    :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param node_item: Node Type, Node type
@@ -411,13 +417,14 @@ def link_viewer():
     pass
 
 
-def links_cut(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                 'bpy_prop_collection'] = None,
+def links_cut(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
               cursor: int = 9):
     ''' Use the mouse to cut (remove) some links
 
     :param path: path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -673,14 +680,15 @@ def select_grouped(extend: bool = False,
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select nodes using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
