@@ -26,13 +26,13 @@ def connect_hair(all: bool = False):
     pass
 
 
-def copy_particle_systems(space: typing.Union[str, int] = 'OBJECT',
+def copy_particle_systems(space: typing.Union[int, str] = 'OBJECT',
                           remove_target_particles: bool = True,
                           use_active: bool = False):
     ''' Copy particle systems from the active object to selected objects
 
     :param space: Space, Space transform for copying from one object to another * OBJECT Object, Copy inside each object's local space. * WORLD World, Copy in world space.
-    :type space: typing.Union[str, int]
+    :type space: typing.Union[int, str]
     :param remove_target_particles: Remove Target Particles, Remove particle systems on the target objects
     :type remove_target_particles: bool
     :param use_active: Use Active, Use the active particle system from the context
@@ -42,11 +42,11 @@ def copy_particle_systems(space: typing.Union[str, int] = 'OBJECT',
     pass
 
 
-def delete(type: typing.Union[str, int] = 'PARTICLE'):
+def delete(type: typing.Union[int, str] = 'PARTICLE'):
     ''' Delete selected particles or keys
 
     :param type: Type, Delete a full particle or only keys
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -184,11 +184,11 @@ def reveal():
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' (De)select all particles' keys
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -224,8 +224,8 @@ def select_more():
 
 def select_random(percent: float = 50.0,
                   seed: int = 0,
-                  action: typing.Union[str, int] = 'SELECT',
-                  type: typing.Union[str, int] = 'HAIR'):
+                  action: typing.Union[int, str] = 'SELECT',
+                  type: typing.Union[int, str] = 'HAIR'):
     ''' Select a randomly distributed set of hair or points
 
     :param percent: Percent, Percentage of objects to select randomly
@@ -233,29 +233,29 @@ def select_random(percent: float = 50.0,
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     :param type: Type, Select either hair or points
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_roots(action: typing.Union[str, int] = 'SELECT'):
+def select_roots(action: typing.Union[int, str] = 'SELECT'):
     ''' Select roots of all visible particles
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_tips(action: typing.Union[str, int] = 'SELECT'):
+def select_tips(action: typing.Union[int, str] = 'SELECT'):
     ''' Select tips of all visible particles
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
