@@ -73,11 +73,11 @@ def eyedropper_depth():
     pass
 
 
-def eyedropper_driver(mapping_type: typing.Union[str, int] = 'SINGLE_MANY'):
+def eyedropper_driver(mapping_type: typing.Union[int, str] = 'SINGLE_MANY'):
     ''' Pick a property to use as a driver target
 
     :param mapping_type: Mapping Type, Method used to match target and driven properties * SINGLE_MANY All from Target, Drive all components of this property using the target picked. * DIRECT Single from Target, Drive this component of this property using the target picked. * MATCH Match Indices, Create drivers for each pair of corresponding elements. * NONE_ALL Manually Create Later, Create drivers for all properties without assigning any targets yet. * NONE_SINGLE Manually Create Later (Single), Create driver for this property only and without assigning any targets yet.
-    :type mapping_type: typing.Union[str, int]
+    :type mapping_type: typing.Union[int, str]
     '''
 
     pass
