@@ -333,14 +333,15 @@ def select_border(pinned: bool = False,
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select UVs using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -490,8 +491,10 @@ def stitch(use_limit: bool = False,
            clear_seams: bool = True,
            mode: typing.Union[int, str] = 'VERTEX',
            stored_mode: typing.Union[int, str] = 'VERTEX',
-           selection: typing.Union[typing.List['bpy.types.SelectedUvElement'],
-                                   'bpy_prop_collection'] = None):
+           selection: typing.
+           Union[typing.Dict[str, 'bpy.types.SelectedUvElement'], typing.
+                 List['bpy.types.SelectedUvElement'],
+                 'bpy_prop_collection'] = None):
     ''' Stitch selected UV vertices by proximity
 
     :param use_limit: Use Limit, Stitch UVs within a specified limit distance
@@ -511,7 +514,7 @@ def stitch(use_limit: bool = False,
     :param stored_mode: Stored Operation Mode, Use vertex or edge stitching
     :type stored_mode: typing.Union[int, str]
     :param selection: Selection
-    :type selection: typing.Union[typing.List['bpy.types.SelectedUvElement'], 'bpy_prop_collection']
+    :type selection: typing.Union[typing.Dict[str, 'bpy.types.SelectedUvElement'], typing.List['bpy.types.SelectedUvElement'], 'bpy_prop_collection']
     '''
 
     pass
