@@ -295,34 +295,35 @@ def appconfig_default():
     pass
 
 
-def append(
-        filepath: str = "",
-        directory: str = "",
-        filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
-        filter_blender: bool = True,
-        filter_backup: bool = False,
-        filter_image: bool = False,
-        filter_movie: bool = False,
-        filter_python: bool = False,
-        filter_font: bool = False,
-        filter_sound: bool = False,
-        filter_text: bool = False,
-        filter_btx: bool = False,
-        filter_collada: bool = False,
-        filter_alembic: bool = False,
-        filter_folder: bool = True,
-        filter_blenlib: bool = True,
-        filemode: int = 1,
-        display_type: typing.Union[int, str] = 'DEFAULT',
-        sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
-        link: bool = False,
-        autoselect: bool = True,
-        active_layer: bool = True,
-        instance_groups: bool = False,
-        set_fake: bool = False,
-        use_recursive: bool = True):
+def append(filepath: str = "",
+           directory: str = "",
+           filename: str = "",
+           files: typing.
+           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+                 List['bpy.types.OperatorFileListElement'],
+                 'bpy_prop_collection'] = None,
+           filter_blender: bool = True,
+           filter_backup: bool = False,
+           filter_image: bool = False,
+           filter_movie: bool = False,
+           filter_python: bool = False,
+           filter_font: bool = False,
+           filter_sound: bool = False,
+           filter_text: bool = False,
+           filter_btx: bool = False,
+           filter_collada: bool = False,
+           filter_alembic: bool = False,
+           filter_folder: bool = True,
+           filter_blenlib: bool = True,
+           filemode: int = 1,
+           display_type: typing.Union[int, str] = 'DEFAULT',
+           sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
+           link: bool = False,
+           autoselect: bool = True,
+           active_layer: bool = True,
+           instance_groups: bool = False,
+           set_fake: bool = False,
+           use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -332,7 +333,7 @@ def append(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1123,8 +1124,10 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         filter_blender: bool = True,
         filter_backup: bool = False,
         filter_image: bool = False,
@@ -1153,7 +1156,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1196,8 +1199,10 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1228,7 +1233,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1403,8 +1408,10 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1417,7 +1424,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1442,8 +1449,10 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1456,7 +1465,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
