@@ -269,19 +269,19 @@ class Curve:
         '''
         pass
 
-    def push_vertex_back(self, vertex: typing.Union['CurvePoint', 'SVertex']):
+    def push_vertex_back(self, vertex: typing.Union['SVertex', 'CurvePoint']):
         ''' Adds a single vertex at the end of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: typing.Union['CurvePoint', 'SVertex']
+        :type vertex: typing.Union['SVertex', 'CurvePoint']
         '''
         pass
 
-    def push_vertex_front(self, vertex: typing.Union['CurvePoint', 'SVertex']):
+    def push_vertex_front(self, vertex: typing.Union['SVertex', 'CurvePoint']):
         ''' Adds a single vertex at the front of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: typing.Union['CurvePoint', 'SVertex']
+        :type vertex: typing.Union['SVertex', 'CurvePoint']
         '''
         pass
 
